ExponentialHistogram

Struct ExponentialHistogram 

pub struct ExponentialHistogram { /* private fields */ }
A histogram with exponential buckets.

This histogram maintains 92 buckets, one for each value or range below, listing ranges by their lower endpoints:

  • 0
  • 1, 2, 3, … 9
  • 10, 20, 30, … 90
  • 100, 200, 300, … 900
  • 1000, 2000, 3000, … 9000
  • 10_000, 20_000, 30_000, … 90_000
  • 100_000, 200_000, 300_000, … 900_000
  • 1_000_000, 2_000_000, 3_000_000, … 9_000_000
  • 10_000_000, 20_000_000, 30_000_000, … 90_000_000
  • 100_000_000, 200_000_000, 300_000_000, … 900_000_000
  • 1_000_000_000, 2_000_000_000, 3_000_000_000, … 9_000_000_000
  • 10_000_000_000 through u64::MAX.

Implementations

Source

impl ExponentialHistogram

pub const fn new() -> Self

Constructs a new exponential histogram.

pub fn record(&self, value: impl TryInto<u64>)

Records value in the histogram.

pub fn record_elapsed(&self, start: Instant)

Records the time elapsed since start in the histogram, as a count of microseconds.

pub fn record_duration(&self, duration: Duration)

Records duration as a count of microseconds.

pub fn snapshot(&self) -> ExponentialHistogramSnapshot

Returns a snapshot of the histogram.

pub fn sum(&self) -> u64

Returns the sum of the values in the histogram

pub fn record_callback<F, T>(&self, f: F) -> T
where F: FnOnce() -> T,

Calls f and records the amount of time that it takes to run, in microseconds, in the histogram.