pub struct SlidingHistogram { /* private fields */ }Expand description
A sliding histogram with exponential buckets.
This histogram records up to a specified number of samples across a specified maximum amount of time. Within that range, it maintains an exponential histogram with the same form as ExponentialHistogram.
Implementations
Sourceimpl SlidingHistogram
impl SlidingHistogram
Sourcepub const fn new(max_samples: usize, max_elapsed: Duration) -> Self
pub const fn new(max_samples: usize, max_elapsed: Duration) -> Self
Constructs a new sliding histogram. The histogram will keep at most the
most recent max_samples samples that have been recorded over at most
the most recent max_elapsed amount of time.
Sourcepub fn record_elapsed(&mut self, start: Instant)
pub fn record_elapsed(&mut self, start: Instant)
Records the time elapsed since start in the histogram, as a count of
microseconds.
Sourcepub fn snapshot(&mut self) -> ExponentialHistogramSnapshot
pub fn snapshot(&mut self) -> ExponentialHistogramSnapshot
Returns a snapshot of the histogram.
Sourcepub fn record_callback<F, T>(&mut self, f: F) -> Twhere
F: FnOnce() -> T,
pub fn record_callback<F, T>(&mut self, f: F) -> Twhere
F: FnOnce() -> T,
Calls f and records the amount of time that it takes to run, in
microseconds, in the histogram.