pub struct ExponentialHistogram { /* private fields */ }Expand description
A histogram with exponential buckets.
This histogram maintains 92 buckets, one for each value or range below, listing ranges by their lower endpoints:
- 0
- 1, 2, 3, … 9
- 10, 20, 30, … 90
- 100, 200, 300, … 900
- 1000, 2000, 3000, … 9000
- 10_000, 20_000, 30_000, … 90_000
- 100_000, 200_000, 300_000, … 900_000
- 1_000_000, 2_000_000, 3_000_000, … 9_000_000
- 10_000_000, 20_000_000, 30_000_000, … 90_000_000
- 100_000_000, 200_000_000, 300_000_000, … 900_000_000
- 1_000_000_000, 2_000_000_000, 3_000_000_000, … 9_000_000_000
- 10_000_000_000 through u64::MAX.
Implementations
Sourceimpl ExponentialHistogram
impl ExponentialHistogram
Sourcepub fn record_elapsed(&self, start: Instant)
pub fn record_elapsed(&self, start: Instant)
Records the time elapsed since start in the histogram, as a count of
microseconds.
Sourcepub fn record_duration(&self, duration: Duration)
pub fn record_duration(&self, duration: Duration)
Records duration as a count of microseconds.
Sourcepub fn snapshot(&self) -> ExponentialHistogramSnapshot
pub fn snapshot(&self) -> ExponentialHistogramSnapshot
Returns a snapshot of the histogram.
Sourcepub fn record_callback<F, T>(&self, f: F) -> Twhere
F: FnOnce() -> T,
pub fn record_callback<F, T>(&self, f: F) -> Twhere
F: FnOnce() -> T,
Calls f and records the amount of time that it takes to run, in
microseconds, in the histogram.